# pytodict (Python object to dict)

pytodict is a library to convert python objects to a dict. This dict can be converted to json, msgpack or other serialized representations

TODO:
* ~~Add to_dict interface class~~
